import { FieldProps } from 'formik';
import React, { Fragment, FunctionComponent, useCallback, useMemo } from 'react';
import DatePicker from 'react-datepicker';

import { TranslatedString } from '../locale';
import { Fieldset, FormField, Label, Legend, TextInput } from '../ui/form';

const OrderComments: FunctionComponent = () => {
    const renderLabel = useCallback(
        (name) => (
            <Label hidden htmlFor={name}>
                <TranslatedString id="shipping.order_comment_label" />
            </Label>
        ),
        [],
    );

    const renderInput = useCallback(
        ({ field }: FieldProps) => <TextInput {...field} autoComplete="off" maxLength={2000} />,
        [],
    );

    const legend = useMemo(
        () => (
            <Legend>
                <TranslatedString id="shipping.order_comment_label" />
            </Legend>
        ),
        [],
    );

    const legendEventDate = useMemo(() => (
        <Legend>
            <TranslatedString id="shipping.event_date_label" />
        </Legend>
    ), []);

    const renderInputExtra = useCallback(({ field, form }: FieldProps) => (
        <DatePicker
            { ...field }
            autoComplete="none"
            shouldCloseOnSelect={false}
            popperClassName="optimizedCheckout-contentPrimary"
            className="form-input optimizedCheckout-form-input"
            dateFormat="MM/dd/yyyy"
            placeholderText={ "MM/dd/yyyy" }
            selected={(field.value && new Date(field.value)) || null}
            onChange={val => {
                form.setFieldValue(field.name, val);
            }}
        />
    ), []);

    const labelContent = useMemo(() => (
        <Fragment>
            <Label hidden htmlFor={ 'eventStartDate' }>
                <TranslatedString id="shipping.event_date_label" />
            </Label>

            { ' ' }

            <p><small><TranslatedString id="shipping.event_date" /></small></p>
        </Fragment>
    ), []);

    return <>
        <Fieldset legend={ legendEventDate } additionalClassName="checkout-shipping-extra-comments" id="shipping-extra-comments">
            <FormField
                input={ renderInputExtra }
                labelContent={ labelContent }
                additionalClassName="event-start-date"
                name="eventStartDate"
            />
        </Fieldset>
        <Fieldset legend={legend} testId="checkout-shipping-comments">
            <FormField input={renderInput} label={renderLabel} name="orderComment" />
        </Fieldset>
    </>;
};

export default OrderComments;
